@@ -14,7 +14,7 @@
 #    under the License.
 #
 
-import mock
+from unittest import mock
 
 from vmware_nsxlib.tests.unit.v3 import nsxlib_testcase
 
