@@ -103,6 +103,20 @@ FAKE_CONTAINER_PORT = {
             "value": "f313290b-eba8-4262-bd93-fab5026e9495",
             "key": "QosSwitchingProfile"
         }
+    ],
+    "extra_configs": [
+        {
+            "config_pair": {
+                "value": "value1",
+                "key": "key1"
+            }
+        },
+        {
+            "config_pair": {
+                "value": "value2",
+                "key": "key2"
+            }
+        }
     ]
 }
 
@@ -222,7 +236,11 @@ FAKE_APPLICATION_PROFILE = {
     "id": FAKE_APPLICATION_PROFILE_UUID,
     "display_name": "httpprofile1",
     "ntlm": False,
+    "request_body_size": 65536,
     "request_header_size": 1024,
+    "response_header_size": 4096,
+    "response_timeout": 60,
+    "http_redirect_to": "redirect_url",
     "http_redirect_to_https": False,
     "idle_timeout": 1800,
     "x_forwarded_for": "INSERT",
@@ -334,7 +352,8 @@ FAKE_SERVICE = {
     "attachment": {
         "target_id": FAKE_ROUTER_UUID,
         "target_type": "LogicalRouter"
-    }
+    },
+    "relax_scale_validation": False
 }
 
 FAKE_TZ_UUID = uuidutils.generate_uuid()
@@ -348,12 +367,32 @@ FAKE_TZ = {
 }
 
 FAKE_TN_UUID = uuidutils.generate_uuid()
+FAKE_TZ_EP_UUID = uuidutils.generate_uuid()
+FAKE_TZ_EP_UUID2 = uuidutils.generate_uuid()
 FAKE_TN = {
     "resource_type": "TransportNode",
     "revision": 0,
     "id": FAKE_TZ_UUID,
     "display_name": FAKE_NAME,
-    "transport_zone_endpoints": [{"transport_zone_id": FAKE_TZ_UUID}]
+    "transport_zone_endpoints": [{"transport_zone_id": FAKE_TZ_UUID}],
+    "host_switch_spec": {
+        "host_switches": [
+            {
+                'transport_zone_endpoints': [
+                    {
+                        'transport_zone_id': FAKE_TZ_EP_UUID
+                    }
+                ]
+            },
+            {
+                'transport_zone_endpoints': [
+                    {
+                        'transport_zone_id': FAKE_TZ_EP_UUID2
+                    }
+                ]
+            }
+        ]
+    }
 }
 
 FAKE_MD_UUID = uuidutils.generate_uuid()
@@ -564,6 +603,7 @@ FAKE_TIERO_ROUTER = {
         "target_id": "c3d80576-e340-403d-a2d0-f4a72a1db6e3"
     }],
     "advanced_config": {
+        "transport_zone_id": FAKE_TZ_UUID,
         "external_transit_networks": ["100.64.0.0/16"],
         "internal_transit_network": "169.254.0.0/28"
     },
@@ -637,3 +677,14 @@ FAKE_CLUSTER_NODES_CONFIG = [{
     },
     "appliance_mgmt_listen_addr": FAKE_MANAGER_IP2
 }]
+
+FAKE_TAGS = [
+    {
+        'scope': 'os-project-id',
+        'tag': 'project-1'
+    },
+    {
+        'scope': 'os-api-version',
+        'tag': '2.1.1.0'
+    }
+]
