@@ -92,13 +92,15 @@ def http_error_to_exception(status_code, error_code, related_error_codes=None):
              '500105': exceptions.NsxOverlapAddresses,
              '500232': exceptions.StaleRevision,  # Missing dependent objects
              '503040': exceptions.NsxSegemntWithVM,
-             '100148': exceptions.StaleRevision},
+             '100148': exceptions.StaleRevision,
+             '500012': exceptions.NsxInvalidPath},
         requests.codes.CONFLICT: exceptions.StaleRevision,
         requests.codes.PRECONDITION_FAILED: exceptions.StaleRevision,
         requests.codes.INTERNAL_SERVER_ERROR:
             {'98': exceptions.CannotConnectToServer,
              '99': exceptions.ClientCertificateNotTrusted,
-             '607': exceptions.APITransactionAborted},
+             '607': exceptions.APITransactionAborted,
+             '610': exceptions.APITransactionAborted},
         requests.codes.FORBIDDEN:
             {'98': exceptions.BadXSRFToken,
              '403': exceptions.InvalidCredentials,
