@@ -213,6 +213,10 @@ class NsxPendingDelete(NsxLibException):
                 "remove the deleted object")
 
 
+class NsxInvalidPath(ManagerError):
+    message = _("Invalid path found: %(details)s")
+
+
 class NsxSegemntWithVM(ManagerError):
     message = _("Cannot delete segment as it still has VMs or VIFs attached")
 
