@@ -17,7 +17,6 @@ import abc
 from distutils import version
 
 from oslo_log import log
-import six
 
 from vmware_nsxlib._i18n import _
 from vmware_nsxlib.v3 import client
@@ -29,8 +28,7 @@ from vmware_nsxlib.v3 import utils
 LOG = log.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class NsxLibBase(object):
+class NsxLibBase(object, metaclass=abc.ABCMeta):
     def __init__(self, nsxlib_config):
 
         self.nsx_version = None
@@ -127,7 +125,7 @@ class NsxLibBase(object):
     # TODO(abhiraut): Revisit this method to generate complex boolean
     #                 queries to search resources.
     def search_by_tags(self, tags, resource_type=None, cursor=None,
-                       page_size=None, **extra_attrs):
+                       page_size=None, silent=False, **extra_attrs):
         """Return the list of resources searched based on tags.
 
         Currently the query only supports AND boolean operator.
@@ -139,6 +137,7 @@ class NsxLibBase(object):
         :param cursor: Opaque cursor to be used for getting next page of
                        records (supplied by current result page).
         :param page_size: Maximum number of results to return in this page.
+        :param silent: Silence the logging if True.
         :param extra_attrs: Support querying by user specified attributes.
                             Multiple attributes will be ANDed.
         """
@@ -162,7 +161,7 @@ class NsxLibBase(object):
         @utils.retry_upon_exception(exceptions.NsxSearchError,
                                     max_attempts=self.client.max_attempts)
         def do_search(url):
-            return self.client.url_get(url)
+            return self.client.url_get(url, silent=silent)
 
         return do_search(url)
 
