@@ -370,11 +370,18 @@ class LogicalRouterPort(utils.NsxLibApiBase):
             manager=self.client.nsx_api_managers,
             operation="get router link port")
 
-    def get_tier0_uplink_port(self, logical_router_id):
+    def get_tier0_uplink_ports(self, logical_router_id):
         logical_router_ports = self.get_by_router_id(logical_router_id)
+        ports = []
         for port in logical_router_ports:
             if port['resource_type'] == nsx_constants.LROUTERPORT_UPLINK:
-                return port
+                ports.append(port)
+        return ports
+
+    def get_tier0_uplink_port(self, logical_router_id):
+        ports = self.get_tier0_uplink_ports(logical_router_id)
+        if ports:
+            return ports[0]
 
     def get_tier0_uplink_subnets(self, logical_router_id):
         port = self.get_tier0_uplink_port(logical_router_id)
@@ -571,7 +578,7 @@ class IpPool(utils.NsxLibApiBase):
         url = pool_id
         if force:
             url += '?force=%s' % force
-        return self.client.delete(self.get_path(url))
+        return self._delete_by_path_with_retry(self.get_path(url))
 
     def _update_param_in_pool(self, args_dict, key, pool_data):
         # update the arg only if it exists in the args dictionary
@@ -789,7 +796,7 @@ class Inventory(utils.NsxLibApiBase):
         request_url = "%s?container_cluster_id=%s" % (
             self.get_path(self._get_path_for_resource(resource_type)),
             cluster_id)
-        return self.client.url_get(request_url)
+        return self.client.url_list(request_url)
 
     def delete(self, resource_type, resource_id):
         if not resource_type:
